@@ -35,6 +35,10 @@ class LoginDomain(Enum):
 	test2_djc = "https://www.djctest2.gm/"
 	test2_zcj = 'https://www.cqzcjtest2.gm/'
 	test2_xcj = 'https://www.xcjtest2.gm/'
+	# test2配置
+	test3_djc = "https://www.djctest3.gm/"
+	test3_zcj = 'https://www.cqzcjtest3.gm/'
+	test3_xcj = 'https://www.xcjtest3.gm/'
 
 
 
@@ -97,6 +101,32 @@ class LoginData(Enum):
 		'state': '{"client_id": "plat@XCJ", "scope": "www.cqzcjshow.com", "redirect_uri": "https://www.cqzcjshow.com/gateway/v1/login"}'
 	}
 
+	zcj_test3_login_data_dict = {
+		'origin': 'https://www.cqzcjtest3.gm',
+		'password': '402522cea3acc6228192fec58a7b8a79',
+		'client_id': 'plat@ZCJ',
+		'scope': 'www.cqzcjtest3.gm',
+		'options': '',
+		'response_type': 'code',
+		'redirect_uri': 'https://www.cqzcjtest3.gm/gateway/v1/login',
+		'certLoginProvider': 'ezca',
+		'success_uri': 'https://www.cqzcjtest3.gm/login-app/login-success/index.html',
+		'state': '{"client_id": "plat@ZCJ", "scope": "www.cqzcjtest3.gm", "redirect_uri": "https://www.cqzcjtest3.gm/gateway/v1/login"}'
+	}
+
+	xcj_test3_login_data_dict = {
+		'origin': 'https://www.xcjtest3.gm',
+		'password': '402522cea3acc6228192fec58a7b8a79',
+		'client_id': 'plat@XCJ',
+		'scope': 'www.xcjtest3.gm',
+		'options': '',
+		'response_type': 'code',
+		'redirect_uri': 'https://www.xcjtest3.gm/gateway/v1/login',
+		'certLoginProvider': 'ezca',
+		'success_uri': 'https://www.xcjtest3.gm/login-app/login-success/index.html',
+		'state': '{"client_id": "plat@XCJ", "scope": "www.xcjtest3.gm", "redirect_uri": "https://www.xcjtest3.gm/gateway/v1/login"}'
+	}
+
 def _second_verify(resp, login_org):
 	"""第一次验证不通过时获取返回值，并传入待登录的单位名称，返回EMPLOEE"""
 	try:
@@ -264,6 +294,7 @@ def login(session, env, host, user_name, org_name=None):
 			print(f"达到最大重试次数 {max_retries}，登录失败")
 	except AttributeError:
 		raise ValueError(f'Invalid environment: {env}')
+
 # 登录后切换身份，例如此账号有供应商、采购单位、财政等多种身份，根据您的需求进行切换；
 def switch_login_identity(session, env, orgType):
 	"""登录后切换身份，例如此账号有供应商、采购单位、财政等多种身份，根据您的需求进行切换"""
